@@ -1,6 +1,8 @@
 /*
  * main.c -- Main file, basic initialization
- * Copyright (C) 2007, 2008 Alberto Garcia <agarcia@igalia.com>
+ *
+ * Copyright (C) 2007-2009 Igalia, S.L.
+ * Authors: Alberto Garcia <agarcia@igalia.com>
  *
  * This file is part of Vagalume.
  *
@@ -27,23 +29,32 @@
 #include "globaldefs.h"
 #include "audio.h"
 
-#ifdef SET_IM_STATUS
+#ifdef HAVE_DBUS_SUPPORT
 #   include <dbus/dbus-glib.h>
 #endif
 
+#ifdef MAEMO5
+#   include <hildon/hildon.h>
+#endif
+
 int
-main (int argc, char **argv)
+main                                    (int    argc,
+                                         char **argv)
 {
         char *radio = NULL;
 
         signal(SIGPIPE, SIG_IGN);
         g_thread_init (NULL);
         gdk_threads_init ();
-#ifdef SET_IM_STATUS
+#ifdef HAVE_DBUS_SUPPORT
         dbus_g_thread_init ();
 #endif
         gdk_threads_enter ();
+#ifdef MAEMO5
+        hildon_gtk_init (&argc, &argv);
+#else
         gtk_init (&argc, &argv);
+#endif /* MAEMO5 */
         g_set_application_name(APP_NAME);
 
         bindtextdomain (GETTEXT_PACKAGE, VAGALUME_LOCALE_DIR);
@@ -52,7 +63,7 @@ main (int argc, char **argv)
 
 #if defined(HAVE_GETOPT) && !defined(MAEMO)
         int opt;
-        while ((opt = getopt(argc, argv, "c:d:s:h")) != -1) {
+        while ((opt = getopt(argc, argv, "c:d:m:s:h")) != -1) {
                 switch (opt) {
                 case 'c':
                         g_setenv(GST_CONVERT_ENVVAR, optarg, TRUE);
@@ -60,21 +71,27 @@ main (int argc, char **argv)
                 case 'd':
                         g_setenv(GST_DECODER_ENVVAR, optarg, TRUE);
                         break;
+                case 'm':
+                        g_setenv(GST_MIXER_ENVVAR, optarg, TRUE);
+                        break;
                 case 's':
                         g_setenv(GST_SINK_ENVVAR, optarg, TRUE);
                         break;
                 default:
-                        g_print(_("Usage: %s [-c converter] [-d decoder] "
-                                  "[-s sink] [lastfm radio url]\n\n"
+                        g_print(_("Usage:\n  %s [-c converter] [-d decoder] "
+                                  "[-m mixer] [-s sink] [lastfm radio url]\n\n"
                                   "  converter: GStreamer converter "
                                   "(default: '%s', 'none' to disable)\n"
                                   "  decoder:   GStreamer decoder "
                                   "(default: '%s')\n"
+                                  "  mixer:     GStreamer mixer "
+                                  "(default: '%s')\n"
                                   "  sink:      GStreamer sink "
                                   "(default: '%s')\n"),
                                 argv[0],
                                 lastfm_audio_default_convert_name(),
                                 lastfm_audio_default_decoder_name(),
+                                lastfm_audio_default_mixer_name(),
                                 lastfm_audio_default_sink_name());
                         return -1;
                 }
